WebAuthProvider class

Inheritance
  • Object
  • AuthClient
  • WebAuthProvider

Constructors

WebAuthProvider({required String scheme, Identity? identity, String path = "", SignIdentity? key, DelegationChain? chain, Uri? authUri, AuthFunction authFunction = webAuth, bool useLocalPage = true, int port = 32768})

Properties

authFunction ↔ AuthFunction
getter/setter pairinherited
authUri ↔ Uri?
getter/setter pairinherited
chain ↔ DelegationChain?
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
identity ↔ Identity?
getter/setter pairinherited
key ↔ SignIdentity?
getter/setter pairinherited
path ↔ String
getter/setter pairinherited
port ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scheme ↔ String
getter/setter pairinherited
server ↔ HttpServer?
getter/setter pair
useLocalPage ↔ bool
getter/setter pair

Methods

getIdentity() → Identity?
inherited
handleFailure(String? errorMessage, void onError(String? error)?) → void
override
handleSuccess(AuthResponseSuccess message, void onSuccess()?) → void
inherited
isAuthenticated() → Future<bool>
inherited
login([AuthClientLoginOptions? options]) → Future<void>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
start([AuthClientLoginOptions? options]) → Future<void>
toStorage() → String
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited